//// [parserGreaterThanTokenAmbiguity5.ts]
1 
// before
>> // after
2;

//// [parserGreaterThanTokenAmbiguity5.js]
1
    >>
        2;
